@@ -33,11 +33,6 @@ class Console::CommandDispatcher::Core
     @transport_map = {}
   end
 
-  @@irb_opts = Rex::Parser::Arguments.new(
-    '-h' => [false, 'Help menu.'             ],
-    '-e' => [true,  'Expression to evaluate.']
-  )
-
   @@load_opts = Rex::Parser::Arguments.new(
     '-h' => [false, 'Help menu.'                    ],
     '-l' => [false, 'List all available extensions.']
@@ -301,49 +296,12 @@ class Console::CommandDispatcher::Core
     print_good("Successfully created #{opts[:type]} pivot.")
   end
 
-  def cmd_sessions_help
-    print_line('Usage: sessions <id>')
-    print_line
-    print_line('Interact with a different session Id.')
-    print_line('This works the same as calling this from the MSF shell: sessions -i <session id>')
-    print_line
-  end
-
-  def cmd_sessions(*args)
-    if args.length == 0 || args[0].to_i == 0
-      cmd_sessions_help
-    elsif args[0].to_s == client.name.to_s
-      print_status("Session #{client.name} is already interactive.")
-    else
-      print_status("Backgrounding session #{client.name}...")
-      # store the next session id so that it can be referenced as soon
-      # as this session is no longer interacting
-      client.next_session = args[0]
-      client.interacting = false
-    end
-  end
-
   def cmd_secure
     print_status('Negotiating new encryption key ...')
     client.core.secure
     print_good('Done.')
   end
 
-  def cmd_background_help
-    print_line('Usage: background')
-    print_line
-    print_line('Stop interacting with this session and return to the parent prompt')
-    print_line
-  end
-
-  def cmd_background
-    print_status("Backgrounding session #{client.name}...")
-    client.interacting = false
-  end
-
-  alias cmd_bg cmd_background
-  alias cmd_bg_help cmd_background_help
-
   #
   # Displays information about active channels
   #
@@ -500,18 +458,6 @@ class Console::CommandDispatcher::Core
     return tab_complete_channels
   end
 
-  #
-  # Terminates the meterpreter session.
-  #
-  def cmd_exit(*args)
-    print_status('Shutting down Meterpreter...')
-    client.core.shutdown rescue nil
-    client.shutdown_passive_dispatcher
-    shell.stop
-  end
-
-  alias cmd_quit cmd_exit
-
   def cmd_detach_help
     print_line('Detach from the victim. Only possible for non-stream sessions (http/https)')
     print_line
@@ -565,88 +511,9 @@ class Console::CommandDispatcher::Core
 
   alias cmd_interact_tabs cmd_close_tabs
 
-  def cmd_irb_help
-    print_line('Usage: irb')
-    print_line
-    print_line('Open an interactive Ruby shell on the current session.')
-    print @@irb_opts.usage
-  end
-
-  def cmd_irb_tabs(str, words)
-    return [] if words.length > 1
-    @@irb_opts.option_keys
-  end
-
-  #
-  # Open an interactive Ruby shell on the current session
-  #
-  def cmd_irb(*args)
-    expressions = []
-
-    # Parse the command options
-    @@irb_opts.parse(args) do |opt, idx, val|
-      case opt
-      when '-e'
-        expressions << val
-      when '-h'
-        return cmd_irb_help
-      end
-    end
-
-    session = client
-    framework = client.framework
-
-    if expressions.empty?
-      print_status('Starting IRB shell...')
-      print_status("You are in the \"client\" (session) object\n")
-      Rex::Ui::Text::Shell::HistoryManager.with_context(name: :irb) do
-        Rex::Ui::Text::IrbShell.new(client).run
-      end
-    else
-      # XXX: No vprint_status here
-      if framework.datastore['VERBOSE'].to_s == 'true'
-        print_status("You are executing expressions in #{binding.receiver}")
-      end
-
-      expressions.each { |expression| eval(expression, binding) }
-    end
-  end
-
-  def cmd_pry_help
-    print_line 'Usage: pry'
-    print_line
-    print_line 'Open the Pry debugger on the current session.'
-    print_line
-  end
-
-  #
-  # Open the Pry debugger on the current session
-  #
-  def cmd_pry(*args)
-    if args.include?('-h')
-      cmd_pry_help
-      return
-    end
-
-    begin
-      require 'pry'
-    rescue LoadError
-      print_error('Failed to load Pry, try "gem install pry"')
-      return
-    end
-
-    print_status('Starting Pry shell...')
-    print_status("You are in the \"client\" (session) object\n")
-
-    Pry.config.history_load = false
-    Rex::Ui::Text::Shell::HistoryManager.with_context(history_file: Msf::Config.pry_history, name: :pry) do
-      client.pry
-    end
-  end
-
   @@set_timeouts_opts = Rex::Parser::Arguments.new(
     '-c' => [true, 'Comms timeout (seconds)'],
-    '-x' => [true, 'Expiration timout (seconds)'],
+    '-x' => [true, 'Expiration timeout (seconds)'],
     '-t' => [true, 'Retry total time (seconds)'],
     '-w' => [true, 'Retry wait time (seconds)'],
     '-h' => [false, 'Help menu'])
@@ -881,7 +748,7 @@ class Console::CommandDispatcher::Core
     '-N' => [true, 'Proxy password for HTTP/S transports (optional)'],
     '-B' => [true, 'Proxy type for HTTP/S transports (optional: http, socks; default: http)'],
     '-C' => [true, 'Comms timeout (seconds) (default: same as current session)'],
-    '-X' => [true, 'Expiration timout (seconds) (default: same as current session)'],
+    '-X' => [true, 'Expiration timeout (seconds) (default: same as current session)'],
     '-T' => [true, 'Retry total time (seconds) (default: same as current session)'],
     '-W' => [true, 'Retry wait time (seconds) (default: same as current session)'],
     '-v' => [false, 'Show the verbose format of the transport list'],
@@ -1731,76 +1598,6 @@ class Console::CommandDispatcher::Core
     return true
   end
 
-  def cmd_resource_help
-    print_line "Usage: resource path1 [path2 ...]"
-    print_line
-    print_line "Run the commands stored in the supplied files. (- for stdin, press CTRL+D to end input from stdin)"
-    print_line "Resource files may also contain ERB or Ruby code between <ruby></ruby> tags."
-    print_line
-  end
-
-  def cmd_resource(*args)
-    if args.empty?
-      cmd_resource_help
-      return false
-    end
-
-    args.each do |res|
-      good_res = nil
-      if res == '-'
-        good_res = res
-      elsif ::File.exist?(res)
-        good_res = res
-      elsif
-        # let's check to see if it's in the scripts/resource dir (like when tab completed)
-        [
-          ::Msf::Config.script_directory + ::File::SEPARATOR + 'resource' + ::File::SEPARATOR + 'meterpreter',
-          ::Msf::Config.user_script_directory + ::File::SEPARATOR + 'resource' + ::File::SEPARATOR + 'meterpreter'
-        ].each do |dir|
-          res_path = dir + ::File::SEPARATOR + res
-          if ::File.exist?(res_path)
-            good_res = res_path
-            break
-          end
-        end
-      end
-      if good_res
-        client.console.load_resource(good_res)
-      else
-        print_error("#{res} is not a valid resource file")
-        next
-      end
-    end
-  end
-
-  def cmd_resource_tabs(str, words)
-    tabs = []
-    #return tabs if words.length > 1
-    if ( str and str =~ /^#{Regexp.escape(::File::SEPARATOR)}/ )
-      # then you are probably specifying a full path so let's just use normal file completion
-      return tab_complete_filenames(str,words)
-    elsif (not words[1] or not words[1].match(/^\//))
-      # then let's start tab completion in the scripts/resource directories
-      begin
-        [
-          ::Msf::Config.script_directory + ::File::SEPARATOR + 'resource' + ::File::SEPARATOR + 'meterpreter',
-          ::Msf::Config.user_script_directory + ::File::SEPARATOR + 'resource' + ::File::SEPARATOR + 'meterpreter',
-          '.'
-        ].each do |dir|
-          next if not ::File.exist? dir
-          tabs += ::Dir.new(dir).find_all { |e|
-            path = dir + ::File::SEPARATOR + e
-            ::File.file?(path) and ::File.readable?(path)
-          }
-        end
-      rescue Exception
-      end
-    else
-      tabs += tab_complete_filenames(str,words)
-    end
-    return tabs
-  end
-
   def cmd_enable_unicode_encoding
     client.encode_unicode = true
     print_status('Unicode encoding is enabled')
@@ -1892,14 +1689,23 @@ protected
 
   def tab_complete_modules(str, words)
     tabs = []
-    client.framework.modules.post.map do |name,klass|
+    module_metadata = Msf::Modules::Metadata::Cache.instance.get_metadata
+
+    tabs += module_metadata.filter_map do |m|
+      if m.type == 'post' || (m.type == 'exploit' && m.ref_name.match(%r{(multi|#{Regexp.escape(client.platform)})/local/}))
+        "#{m.type}/#{m.ref_name}"
+      end
+    end
+
+    client.framework.modules.post.module_refnames.each do | name |
       tabs << 'post/' + name
     end
     client.framework.modules.module_names('exploit').
       grep(/(multi|#{Regexp.escape(client.platform)})\/local\//).each do |name|
       tabs << 'exploit/' + name
     end
-    return tabs.sort
+
+    tabs.uniq.sort
   end
 
   def tab_complete_channels
